# ***************************************************************************
# Copyright 2014-2020 VMware, Inc.  All rights reserved. VMware Confidential.
# ***************************************************************************
# $Id$
# $DateTime$
# $Change$
# $Author$
# ***************************************************************************
import nsx_logging
try:
    import simplejson
except ImportError:
    import json as simplejson

from cli.commands.cli_command_provider import CliCommandProvider
from cli.utils.location_utils import FilePaths
from cli.utils.node_utils import is_appliance, is_windows
from cli.utils.rest_utils import local_node_request
from compat23 import compat23_httplib


lg = nsx_logging.getLogger("cli.commands.common.cli_config")


class GetCliOutputDateTime(CliCommandProvider):
    def __call__(self, cmd_list):
        cli_output_datetime = None
        if is_appliance():
            status, obj, err, _ = local_node_request("GET", "/node")
            if status == compat23_httplib.OK:
                cli_output_datetime = obj.get("cli_output_datetime")
            else:
                lg.error("Request to get 'cli_output_datetime' status failed")
        else:
            fpath = FilePaths.CLI_CONFIG_FILE if is_windows()\
                        else FilePaths.HOST_CLI_CONFIG_FILE
            try:
                with open(fpath) as fh:
                    data = simplejson.load(fh)
                cli_output_datetime = data.get("cli_output_datetime")
            except Exception:
                lg.error("Unable to read NSX CLI config file")
        if cli_output_datetime is not None:
            return "OK\n\n%s" % simplejson.dumps(
                    {"cli_output_datetime": cli_output_datetime})
        return "MSG_CLI_CONFIG_GET_OUTPUT_DATETIME_FAILED"


class SetCliOutputDateTime(CliCommandProvider):
    def __call__(self, cmd_list):
        status = True if cmd_list[-1] == "enable" else False
        req_obj = {"cli_output_datetime": status}
        result = False
        if is_appliance():
            status, obj, err, _ = local_node_request("PUT", "/node", req_obj)
            if status == compat23_httplib.OK:
                result = True
            else:
                lg.error("Request to set 'cli_output_datetime' status failed")
        else:
            fpath = FilePaths.CLI_CONFIG_FILE if is_windows()\
                        else FilePaths.HOST_CLI_CONFIG_FILE
            try:
                with open(fpath) as fh:
                    data = simplejson.load(fh)
                data.update(req_obj)
                with open(fpath, "w") as fh:
                    simplejson.dump(data, fh, indent=4)
                result = True
            except Exception:
                lg.exception("Unable to perform IO on NSX CLI config file")
        if result:
            return "OK\n\n%s" % simplejson.dumps("")
        return "MSG_CLI_CONFIG_SET_OUTPUT_DATETIME_FAILED"
