# **********************************************************************
# Copyright 2014 VMware, Inc.  All rights reserved. VMware Confidential.
# **********************************************************************
# $Id$
# $DateTime$
# $Change$
# $Author$
# **********************************************************************
import nsx_logging
import os
import json
import uuid

import cli.commands.host_shared.ovs_util as ovs_util

from netaddr import IPNetwork
from cli.commands.cli_command_provider import CliCommandProvider
from cli.commands.lcp_common.nsx_proxy.routing_domain import get_routing_domain_ids


lg = nsx_logging.getLogger("cli.commands.host_kvm.logical_router")


class HostGetLogicalRouterSummary(CliCommandProvider):
    def __call__(self, cmd_list):
        res = []
        lr_port_count = {}
        lr_list = ovs_util.get_lrouter_list() # lport vni vni_status
        for lr in lr_list:
            lr_uuid = lr[0]
            num_ports = len(ovs_util.get_lif_list(lr_uuid));
            res.append({'uuid': lr_uuid, 'id': lr[1],
                        'num_ports': num_ports,
                        'curr_neigh': lr[4],
                        'max_neigh': lr[5]})
        return "OK\n\n%s" % json.dumps(res)

def GetRoutingDomainUuidHelper(rd_id):
        local_dr_vtep = ovs_util.get_dr_vtep()[0] # label, ip, mac, segment
        # list of remote vteps (label, ip, mac, segment)
        rd_vtep_table = ovs_util.get_routing_domain_vtep_table(rd_id)
        res = {}
        res["routing_domain_id"] = rd_id
        res["tunnels"] = []
        for vtep in rd_vtep_table:
            tunnel_interface = ovs_util.run_ovs_vsctl(
                "find", ["int", "options:remote_ip=" + vtep[1]])
            if len(tunnel_interface) == 0:
                continue
            tunnel = {}
            tunnel["Local"] = local_dr_vtep[1]
            tunnel["Local-subnet"] = "/" + local_dr_vtep[3]
            tunnel["Remote"] = vtep[1]
            tunnel["Remote-subnet"] = "/" + vtep[3]
            tunnel["Tunnel"] = tunnel_interface["name"]
            tunnel["ENCAP"] = tunnel_interface["type"].upper()
            res["tunnels"].append(tunnel)
        return res

class GetRoutingDomains(CliCommandProvider):
    def __call__(self, cmd_list):
        res = {}
        rd_list = get_routing_domain_ids()
        res["desired_state"] = rd_list
        rd_details = [ GetRoutingDomainUuidHelper(k) for k in rd_list ]
        res["realized_state"] = rd_details
        return "OK\n\n%s" % json.dumps(res)

class GetRoutingDomainUuid(CliCommandProvider):
    def __call__(self, cmd_list):
        rd_id = cmd_list[2]
        res = GetRoutingDomainUuidHelper(rd_id)
        return "OK\n\n%s" % json.dumps(res)
