# ***************************************************************************
# Copyright 2015-2017 VMware, Inc.  All rights reserved. VMware Confidential.
# ***************************************************************************
# $Id$
# $DateTime$
# $Change$
# $Author$ Abe Wu
# ***************************************************************************
import nsx_logging
import json

from cli.commands.cli_command_provider import CliCommandProvider
from cli.commands.lcp_common.cfgagent.client import get_cfgagent_cli_output
from cli.utils.error_code import ErrorCode as ec

lg = nsx_logging.getLogger("cli.commands.lcp_common.cfgagent.statecache")


def load_response_output(response):
    try:
        if response is None:
            return None
        output = json.loads(response)
    except (TypeError, ValueError) as err:
        lg.error("load response error: %s", err,
                 error_code=ec.INTERNAL_ERROR)
        return None
    return output


class GetCfgagentLocalConfigCacheTable(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_cfgagent_cli_output("cfgagent/config/local")
        output = load_response_output(response)
        if output is None:
            return "CFGAGENT_HOST_CACHE_TABLE_FAILED"

        return "OK\n\n%s" % json.dumps(output)


class GetCfgagentRemoteConfigCacheTable(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_cfgagent_cli_output("cfgagent/config/remote")
        output = load_response_output(response)
        if output is None:
            return "CFGAGENT_HOST_CACHE_TABLE_FAILED"

        return "OK\n\n%s" % json.dumps(output)


class GetCfgagentRemoteLogicalSwitchConfig(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_cfgagent_cli_output("cfgagent/config/lswitch")
        output = load_response_output(response)
        if output is None:
            return "CFGAGENT_HOST_CACHE_TABLE_FAILED"

        return "OK\n\n%s" % json.dumps(output)


class GetCfgagentRemoteLogicalSwitchPortConfig(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_cfgagent_cli_output("cfgagent/config/lport")
        output = load_response_output(response)
        if output is None:
            return "CFGAGENT_HOST_CACHE_TABLE_FAILED"

        return "OK\n\n%s" % json.dumps(output)


class GetCfgagentLogicalSwitchPortListConfig(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_cfgagent_cli_output("cfgagent/config/lsportlist")
        output = load_response_output(response)
        if output is None:
            return "CFGAGENT_HOST_CACHE_TABLE_FAILED"

        return "OK\n\n%s" % json.dumps(output)


class GetCfgagentRemoteTransportNodeConfig(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_cfgagent_cli_output("cfgagent/config/tnode")
        output = load_response_output(response)
        if output is None:
            return "CFGAGENT_HOST_CACHE_TABLE_FAILED"

        return "OK\n\n%s" % json.dumps(output)


class GetCfgagentRemoteBridgeClusterConfig(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_cfgagent_cli_output("cfgagent/config/bcluster")
        output = load_response_output(response)
        if output is None:
            return "CFGAGENT_HOST_CACHE_TABLE_FAILED"

        return "OK\n\n%s" % json.dumps(output)


class GetCfgagentRemoteMirrorConfig(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_cfgagent_cli_output("cfgagent/config/mirror")
        output = load_response_output(response)
        if output is None:
            return "CFGAGENT_HOST_CACHE_TABLE_FAILED"

        return "OK\n\n%s" % json.dumps(output)


class GetCfgagentRemoteIpfixConfig(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_cfgagent_cli_output("cfgagent/config/ipfix")
        output = load_response_output(response)
        if output is None:
            return "CFGAGENT_HOST_CACHE_TABLE_FAILED"

        return "OK\n\n%s" % json.dumps(output)


class GetCfgagentRemoteProfileConfig(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_cfgagent_cli_output("cfgagent/config/profile")
        output = load_response_output(response)
        if output is None:
            return "CFGAGENT_HOST_CACHE_TABLE_FAILED"

        return "OK\n\n%s" % json.dumps(output)


class GetCfgagentRemoteGroupRelationConfig(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_cfgagent_cli_output("cfgagent/config/grelation")
        output = load_response_output(response)
        if output is None:
            return "CFGAGENT_HOST_CACHE_TABLE_FAILED"

        return "OK\n\n%s" % json.dumps(output)


class GetCfgagentRemoteContainerConfig(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_cfgagent_cli_output("cfgagent/config/container")
        output = load_response_output(response)
        if output is None:
            return "CFGAGENT_HOST_CACHE_TABLE_FAILED"

        return "OK\n\n%s" % json.dumps(output)


class GetCfgagentLocalL2CacheTable(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_cfgagent_cli_output("cfgagent/l2/local")
        output = load_response_output(response)
        if output is None:
            return "CFGAGENT_HOST_CACHE_TABLE_FAILED"

        return "OK\n\n%s" % json.dumps(output)


class GetCfgagentRemoteL2CacheTable(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_cfgagent_cli_output("cfgagent/l2/remote")
        output = load_response_output(response)
        if output is None:
            return "CFGAGENT_HOST_CACHE_TABLE_FAILED"

        return "OK\n\n%s" % json.dumps(output)


class GetCfgagentRemoteL3CacheTable(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_cfgagent_cli_output("cfgagent/l3/remote")
        output = load_response_output(response)
        if output is None:
            return "CFGAGENT_HOST_CACHE_TABLE_FAILED"

        return "OK\n\n%s" % json.dumps(output)


class GetCfgagentCacheTable(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_cfgagent_cli_output("cfgagent/cache/table")
        output = load_response_output(response)
        if output is None:
            return "CFGAGENT_HOST_CACHE_TABLE_FAILED"

        return "OK\n\n%s" % json.dumps(output)


class GetCfgagentCacheTableSize(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_cfgagent_cli_output("cfgagent/cache/size")
        output = load_response_output(response)
        if output is None:
            return "CFGAGENT_HOST_CACHE_TABLE_FAILED"

        return "OK\n\n%s" % json.dumps(output)


class GetCfgagentUplinkTable(CliCommandProvider):
    def __call__(self, cmd_list):
        response = get_cfgagent_cli_output("cfgagent/config/uplink")
        output = load_response_output(response)
        if output is None:
            return "CFGAGENT_HOST_CACHE_TABLE_FAILED"

        return "OK\n\n%s" % json.dumps(output)
