# **********************************************************************
# Copyright 2014 VMware, Inc.  All rights reserved. VMware Confidential.
# **********************************************************************
# $Id$
# $DateTime$
# $Change$
# $Author$
# **********************************************************************


# This module originally developed in NSXmh cloudnet repo:
# cloudnet/src/python/management_api/descriptors/type_descriptor.py


__all__ = ["TypeDescriptor", "TYPE_SCHEMA"]


import nsx_logging
import os
import yaml

from lib.json_schema import JsonSchema
from cli.descriptors.descriptor import Descriptor
from cli.descriptors.descriptor import SCHEMA_REGISTRY


lg = nsx_logging.getLogger("cli.descriptors.type_descriptor")


JSON_META_RAW_SCHEMA = yaml.load(open(JsonSchema.META_SCHEMA_PATH, 'r').read(), Loader=yaml.Loader)
JSON_META_SCHEMA = JsonSchema(
    JSON_META_RAW_SCHEMA, strict=True,
    type_path=["http://json-schema.org/draft-03/schema#"],
    schema_registry=SCHEMA_REGISTRY)

TYPE_SCHEMA_FILE = os.path.join(os.path.dirname(__file__),
                                  'type_descriptor.yml')
TYPE_RAW_SCHEMA = yaml.load(open(TYPE_SCHEMA_FILE), Loader=yaml.Loader).raw_spec
TYPE_SCHEMA = JsonSchema(TYPE_RAW_SCHEMA, schema_registry=SCHEMA_REGISTRY,
                         type_path=["Type"], strict=True)


class TypeDescriptor(Descriptor):
    """Descriptor specification of a data type.

    This class provides a class for representing data types defined by
    a JsonSchema in YAML Descriptor format.
    """

    yaml_tag = '!Type'

    spec_schema = TYPE_SCHEMA

    def __init__(self, id, schema_spec):
        super(TypeDescriptor, self).__init__(id, schema_spec)
        self._schema = JsonSchema(schema_spec, strict=True,
                                  schema_registry=SCHEMA_REGISTRY,
                                  type_path=['#', id])

    @property
    def raw_schema(self):
        return self._schema.raw_schema()

    @property
    def meta_spec(self):
        return self._schema.raw_schema()

    def validate(self, data):
        """Validate that data conforms to the type schema.

        Returns:
            A tuple of (validates_boolean, reason_string):
                validates_boolean: True iff data successfully validates
                    against type.
                reason_string: Descriptive text describing the validation
                    error, if any.
        """
        return self._schema.validate(data)
