#!/bin/sh

# This script should only be used as directed by the documentation for "restore".

# User will login to the root on ESX/KVM or Edge node and run this script
# This script is used to reset the NSX config from the node.
# When the script is called with 'transport_node' option,
#   it will only delete the logical config and stop serving the network.
# If the node is registered to the NSX Manager as a fabric node,
#   it continues to be that way.
# When the script is called with 'fabric_node' option,
#   it will delete the logical config, stop serving the network and
#   also stop attempting communicating to NSX Manager and NSX Central Control Plane.
# On the Edge node, redirect the user to use the "del nsx" CLI command.

NSXA_MPA_DB=/config/vmware/edge/nsxa-mpa.pb
NSXA_ID_DB=/var/run/vmware/edge/*.saved
NSXPROXY_DB=/etc/vmware/nsx/controller-info.xml

kvm_tn_cleanup() {
    echo "reset_nsx_after_mp_restore.sh: Run transport_node reset on KVM node"
    service nsx-agent stop
    # remove managed bridge
    mbr=$(ovs-vsctl find br external_ids:bridge-id=nsx-managed | grep name | awk '{print $3}')
    [ ! -z $mbr ] && ovs-vsctl del-br $mbr
    # remove transport bridges
    service nsxa reset
    service nsx-agent start
}

reset_nsxproxy() {
    if [ -e $NSXPROXY_DB ]; then
        echo "INFO: Resetting nsx-proxy"
        echo > $NSXPROXY_DB
        case $nodetype in
          nsx-edge)
            su admin -c 'set debug-mode; set nsx-proxy controllers file /etc/vmware/nsx/controller-info.xml'
            ;;
          nsx-esx|nsx-kvm)
            /opt/vmware/nsx-cli/bin/scripts/nsxcli -c \
                'set debug-mode; set nsx-proxy controllers file /etc/vmware/nsx/controller-info.xml'
            ;;
          *)
            echo "reset_nsxproxy: Invalid node-type found"
            ;;
        esac
        if [ $? -ne 0 ]; then
            echo "ERROR: Failed to reset $NSXPROXY_SERVICE_NAME"
        fi
    fi
}

option=$1
nodetype=`cat /etc/nsx_issue | grep node-type | cut -d ' ' -f 2`

if [ $nodetype = "nsx-edge" ]; then
    echo "Please login to CLI and enter debug mode with the command 'set debug'."
    echo "Then enter the command 'del nsx' and follow the interactive steps."
    exit 0
fi

if [ "$option" = "fabric_node" ] || [ "$option" = "transport_node" ]; then
    echo "reset_nsx_after_mp_restore.sh: NSX reset script called with argument $option on $nodetype"
else
    echo "Usage : reset_nsx_after_mp_restore.sh <transport_node | fabric_node>"
    return
fi

case $nodetype in
  nsx-esx)
    echo "reset_nsx_after_mp_restore.sh: Run transport_node reset on ESX node"
    /etc/init.d/nsxa reset
    /etc/init.d/nsx-proxy restart
    ;;
  nsx-kvm)
    kvm_tn_cleanup
    ;;
  *)
    echo "reset_nsx_after_mp_restore.sh: Invalid node-type found"
    ;;
esac

if [ "$option" = "fabric_node" ]; then
  case $nodetype in
    nsx-esx)
        echo "reset_nsx_after_mp_restore.sh: Run fabric_node reset on ESX node"
        /usr/lib64/vmware/nsx-mpa/mpaconfigrestore.sh
        reset_nsxproxy
        ;;
    nsx-kvm)
        echo "reset_nsx_after_mp_restore.sh: Run fabric_node reset on KVM node"
        /opt/vmware/nsx-mpa/mpaconfigrestore.sh
        reset_nsxproxy
        ;;
    *)
        echo "reset_nsx_after_mp_restore.sh: Invalid node-type found"
        ;;
  esac
fi;
