# Copyright (C) 2020 VMware, Inc. All rights reserved.
# -- VMware Confidential

import json
import sys
import traceback

from sha.contrib.metric.edge_base import EdgeBase
from sha.contrib.metric.utils import timeout_cache

class EdgeFWStats(EdgeBase):

    def get_fw_stats(self, interface):
        fw_stats = {}

        # Get firewall interface stats
        # The cost of nsxcli is much higher than edge backend command
        #     """nsxcli -c 'get firewall {} interface stats | json'"""
        # Get firewall interface stats via edge backend command
        cmd_get_stats = ['edge-appctl', '-t', '/var/run/vmware/edge/dpd.ctl', 'fw/show', interface, 'total-stats']
        output = self.run_command_with_time_check(cmd_get_stats)

        fw_stats = json.loads(output)
        self._logger.debug("edge fw stats({}): {}".format(sys.getsizeof(fw_stats), fw_stats))
        return fw_stats

    @timeout_cache(10)
    def usage(self, *args, **kwargs):
        lr_list = None
        try:
            lr_list = self.get_fw_interface_list()
        except Exception as e:
            trace = traceback.format_exc()
            self._logger.warning("Failed to get edge fw interface for T0/T1 lrouter: {}, {}".format(e, trace))
        finally:
            if lr_list is None:
                return None

        lr_stats = {}
        for lr in lr_list:
            if 'interface' not in lr:
                continue

            try:
                fw_stats = self.get_fw_stats(lr['interface'])
            except Exception as e:
                trace = traceback.format_exc()
                self._logger.warning("Failed to get edge fw stats on {}: {}, {}".format(lr['interface'], e, trace))
                fw_stats = None

            if fw_stats is not None:
                lr_stats[lr['type'] + '.' +lr['name']] = fw_stats

        return None if not lr_stats else (self.wavefront_source, lr_stats)
