# Copyright (C) 2020 VMware, Inc. All rights reserved.
# -- VMware Confidential

import queue
import threading
import traceback
import sha.config
from sha.contrib.monitor.abc_base import Monitor
from sha.contrib.monitor.processStatus.internal.client import Client
from sha.contrib.monitor.processStatus.internal.connection import Connection

class IntProcessStatusMonitor(Monitor):
    """
    IntProcessStatusMonitor waits for the process status
    """

    def __init__(self):
        self._logger = sha.config.get_logger(__name__)
        self._stop = None
        self._queue = queue.Queue(200)
        self._msg_handle_thread = threading.Thread(target=self._handle_notif, daemon=True)
        self._msg_recv_thread = threading.Thread(target=self._recv_stats, daemon=True)

    def start(self):
        self._stop = False
        Client().set_queue(self._queue)
        Connection().start(self._queue)
        self._msg_handle_thread.start()
        self._msg_recv_thread.start()

    def _recv_stats(self):
        if not Connection.is_connected:
            return
        try:
            Connection.wait_for_data()
        except Exception as e:
            trace = traceback.format_exc()
            self._logger.warning("PSM:socket is closead, Exception:{}, trace:{}".format(e, trace))
        self._logger.info("PSM:_msg_recv_thread stopped.")

    def _handle_notif(self):
        while not self._stop:
            try:
                notif = self._queue.get(timeout=1)
                self._logger.debug("PSM:notify data is {}".format(notif))
                for (key, data) in notif.items():
                    self.notify(key, data)
                self._queue.task_done()
            except queue.Empty:
                continue
            except Exception as e:
                trace = traceback.format_exc()
                self._logger.error("Process ProcessStatus notification failed, Exception:{}, trace:{}".format(e, trace))
        self._logger.info("PSM:_msg_handle_thread stopped.")

    def wait_to_stop(self):
        self._msg_handle_thread.join()
        self._msg_recv_thread.join()

    def stop(self):
        self._stop = True
        Connection.close()
        Client().stop()
