# Copyright (C) 2020 VMware, Inc. All rights reserved.
# -- VMware Confidential

import sha.config
from sha.contrib.monitor.abc_base import Monitor
from sha.config import ENABLED_MONITORS
from sha.constants import MONITER_METRIC_REPORTED, MONITER_METRIC_FAIL_REPORT

class ProcessStatusMonitor(Monitor):
    """
    ProcessStatusMonitor is a monitor for receiving process status.
    """
    def __init__(self, *args, **kwargs):
        self._logger = sha.config.get_logger(__name__)
        self._internal_monitor = None
        self._init_internal_monitor()
        self._metric_name = ENABLED_MONITORS['ProcessStatusMonitor']
        self._stats = {}

    def _init_internal_monitor(self):
        from sha.contrib.monitor.processStatus.internal import IntProcessStatusMonitor
        self._logger.info("start IntProcessStatusMonitor")
        self._internal_monitor = IntProcessStatusMonitor()

    def _stats_inc(self, field):
        self._stats[field] =  self._stats.get(field, 0) + 1

    def _notify_whiteboard(self, *args):
        key = args[0]
        value = args[1]
        from sha.core.whiteboard import DataWhiteboard
        if not DataWhiteboard.report_data(key, value):
             self._stats_inc(MONITER_METRIC_REPORTED)
        else:
             self._stats_inc(MONITER_METRIC_FAIL_REPORT)

    def start(self):
        if not self._internal_monitor.notify:
            self._internal_monitor.notify = self._notify_whiteboard
        self._internal_monitor.start()

    def stop(self):
        self._logger.info("ProcessStatusMonitor stop.")
        self._internal_monitor.stop()

    def join(self):
        self._logger.info("ProcessStatusMonitor join.")
        self._internal_monitor.wait_to_stop()

    @property
    def internal_monitor(self):
        return self._internal_monitor

    @property
    def metric_name(self):
        return self._metric_name
