# Copyright (C) 2019 VMware, Inc. All rights reserved.
# -- VMware Confidential

import traceback

import sha.config
from sha.core.channel.provider.base import BaseProvider
from sha.contrib.action.exportdata import WavefrontSender


class WfProvider(BaseProvider):
    """The wavefront Provider"""
    def __init__(self):
        self._name = "WavefrontProvider"
        self._logger = sha.config.get_logger(__name__)

    def sync(self, msg):
        try:
            self._logger.debug("before sending metric to WavefrontSender, msg:{}".format(msg))
            if WavefrontSender.isReady():
                WavefrontSender.send_metric_now(msg)
                self._logger.debug('Wavefront metric data ready {}'.format(msg))
            else:
                self._logger.debug('wavefront collector is not ready!')
        except Exception as e:
            trace = traceback.format_exc()
            self._logger.warning("{} failed in sending metric:{}, Exception:{}, trace:{}"
                                 .format(self.name, msg, e, trace))

    def close(self):
        # TODO do we need to clear WavefrontSender here?
        pass

    @property
    def name(self):
        raise self._name
