# Copyright (C) 2020 VMware, Inc. All rights reserved.
# -- VMware Confidential

def report_edge_fw_stats(edge_fw_stats, profile):
    if edge_fw_stats is None or edge_fw_stats['value'] is None:
        return

    # Use specified source to export metrics to wavefront
    wavefront_source = edge_fw_stats['value'][0]
    timestamp = edge_fw_stats['timestamp']

    regex_counter = r'(packet|byte)-.*-(in|out)-(pass|drop)'
    reason_list = [
        "reason-3whs",
        "reason-alg",
        "reason-bad-offset",
        "reason-bad-timestamp",
        "reason-congestion",
        "reason-connection-limit",
        "reason-drop-by-loadbalancer",
        "reason-failed-to-copy-pkt",
        "reason-fragment",
        "reason-half-open-tcp-max",
        "reason-icmp-max",
        "reason-inactive",
        "reason-ip-option",
        "reason-memory",
        "reason-nat-conn-limit",
        "reason-nat64-no-frgm-support",
        "reason-normalize",
        "reason-other-max",
        "reason-proto-cksum",
        "reason-queued-frag",
        "reason-redirect-iface-null",
        "reason-rst-sent",
        "reason-short",
        "reason-spoofguard",
        "reason-src-limit",
        "reason-state-insert",
        "reason-state-limit",
        "reason-state-mismatch",
        "reason-state-reuse",
        "reason-synproxy",
        "reason-tcp-flags",
        "reason-tcp-seqnum",
        "reason-translation",
        "reason-tun-fail",
        "reason-udp-max",
        "reason-update-state",
    ]

    for lr, fw_stats in edge_fw_stats['value'][1].items():

        stats_data = {}
        fw_stats_name = "edge." + lr + ".firewall"

        # firewall stats
        if fw_stats is not None:
            if 'total-stats' in fw_stats:
                fw_total_stats = fw_stats['total-stats']
                stats_data['cps'] = fw_total_stats['cps']

                #stats raw data
                stats_raw_data = {}
                for key, value in fw_total_stats.items():
                    if key in reason_list:
                        stats_raw_data[key] = value
                    elif re.match(regex_counter, key):
                        stats_raw_data[key.replace('byte', 'bytes').replace('packet', 'packets')] = value
                stats_data['stats'] = stats_raw_data

        if stats_data:
            Exportdata(data = {fw_stats_name: stats_data},
                       exports = ['wavefront'],
                       source = wavefront_source,
                       timestamp = timestamp)



profile = data_store['profile']
edge_fw_stats = data_store['metrics']['nsx.edge.edge-fw-stats']
report_edge_fw_stats(edge_fw_stats, profile)
