# Copyright 2013-2017 VMware, Inc.  All rights reserved.
# -*- mode: Python; coding: utf-8 -*-
# **********************************************************
#
"""
Implementation of appliance SNMP API.
"""

__author__ = "VMware, Inc."

import sys
import logging
import vmw_snmp
import traceback

class Cfg(object):
    def __init__(self):
       self.authentication = ""
       self.syslocation = ""
       self.syscontact = ""
       self.communities = []
       self.engineid = ""
       self.loglevel = ""
       self.notraps = []
       self.port = -1
       self.privacy = ""
       self.syscontact = ""
       self.syslocation = ""
       self.targets = []
       self.users = []
       self.remoteusers = []
       self.v3targets = []
       self.v2c = False

def load_config():
    try:
        return vmw_snmp._load_xml_file()
    except Exception as err:
        msg = 'load_config: failed to parse %s, reason %s' % \
              (vmw_snmp.CONFIG_FILE, str(err))
        logging.error(msg)
        tb = traceback.format_exception(*sys.exc_info()[0:3])
        logging.error(msg)
        for line in tb:
            logging.error(line.rstrip())
        logging.error(tb)

def show():
    kvp = load_config()
    kvp['state'] = vmw_snmp._set_pid()
    return kvp

def stats():
    return vmw_snmp.get_stats()

def enable_agent():
    vmw_snmp.enable()

def disable_agent():
    vmw_snmp.disable()

def set_communities(arg):
    kvp = Cfg()
    kvp.communities = arg.split(',')
    vmw_snmp.set_config(kvp)

def set_targets(arg):
    kvp = Cfg()
    kvp.targets = arg.split(',')
    vmw_snmp.set_config(kvp)

def set_port(arg):
    kvp = Cfg()
    kvp.port = arg
    vmw_snmp.set_config(kvp)

def set_loglevel(arg):
    kvp = Cfg()
    kvp.loglevel = arg
    vmw_snmp.set_config(kvp)

def set_filter(arg):
    kvp = Cfg()
    kvp.notraps = arg
    vmw_snmp.set_config(kvp)

def set_contact(arg):
    kvp = Cfg()
    kvp.syscontact = arg
    vmw_snmp.set_config(kvp)

def set_location(arg):
    kvp = Cfg()
    kvp.syslocation = arg
    vmw_snmp.set_config(kvp)

def set_engineid(arg):
    kvp = Cfg()
    kvp.engineid = arg
    vmw_snmp.set_config(kvp)

def set_authentication(arg):
    kvp = Cfg()
    kvp.authentication = arg
    vmw_snmp.set_config(kvp)

def set_privacy(arg):
    kvp = Cfg()
    kvp.privacy = arg
    vmw_snmp.set_config(kvp)

def set_users(arg):
    kvp = Cfg()
    kvp.users = arg.split(',')
    vmw_snmp.set_config(kvp)

def set_v3targets(arg):
    kvp = Cfg()
    kvp.v3targets = arg.split(',')
    vmw_snmp.set_config(kvp)

def set_v2c(arg):
    kvp = Cfg()
    val = False
    if arg == 'true' or arg == '1' or arg == 'True':
        val = True
    kvp.v2c = val
    vmw_snmp.set_config(kvp)

def reset():
    vmw_snmp.reset_config()

def test():
    nopint = True
    return vmw_snmp.test_config(nopint)
